--[[
************************************************************************
Project				: SKG
Author				: zhinjio
Project Revision	: r136
Project Date		: 20090516063018

File				: SKG_GUI_Bid.lua
Commit Author		: zhinjio
Commit Revision		: 120
Commit Date			: 20081222091749
************************************************************************
Description	:
	Definition of the bidding frame, and associated functions.

TODO		:

************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]
local SKG = LibStub( "AceAddon-3.0"):GetAddon( "SKG" )
local SKGL = LibStub( "AceLocale-3.0"):GetLocale( "SKG" )

function SKG_UpdateLootList( )
	-- Clear the list and then rebuild from SKG.LootItems
	local found = false
	for index = 1, SKG_maxVisibleBidItems, 1 do
		if ( SKG.LootItems[index] ~= nil ) then
			SKG_Debug( "biditem " .. index .. " is " .. SKG.LootItems[index].link )
			SKG_BF_BidItems[index]:SetText( SKG.LootItems[index].link )
			found = true
			if ( index == SKG.selectedBidItem ) then
				SKG_BF_BidItems[index]:SetNormalTexture( [[Interface\Addons\SKG\BLP\highlight]] )
				local nTex = SKG_BF_BidItems[index]:GetNormalTexture()
				nTex:SetAllPoints()
				nTex:SetTexCoord( (30/256), (1-(10/256)), (6/32), (1-(6/32)) )
				SKG_BF_BidItems[index]:SetHighlightTexture( [[Interface\Addons\SKG\BLP\highlight]] )
				local hTex = SKG_BF_BidItems[index]:GetHighlightTexture()
				hTex:SetAllPoints()
				hTex:SetTexCoord( (30/256), (1-(10/256)), (6/32), (1-(6/32)) )
			else
				SKG_BF_BidItems[index]:SetNormalTexture( "" )
				SKG_BF_BidItems[index]:SetHighlightTexture( "" )
			end
		else
			-- SKG_Debug( "biditem " .. index .. " is empty" )
			SKG_BF_BidItems[index]:SetText( "" )
			SKG_BF_BidItems[index]:SetNormalTexture( "" )
			SKG_BF_BidItems[index]:SetHighlightTexture( "" )
		end
	end
	if ( found == true ) then
		SKG_BBF_OpenBidButton:Enable()
		SKG_BBF_ArmorFilterChooser:Enable()
		SKG_BBF_ClassFilterChooser:Enable()
		if ( SKG_SECURITY_LEVEL ~= "U" ) then
			SKG_BidButtonFrame:Show()
		end
	end
end

function SKG_RemoveBidItem_OnClick( )

	-- Need to add security

	if ( SKG.selectedBidItem == 0 ) then
		SKG_Print( SKGL["SKG_ERROR_NOBIDITEMSELECTED"] )
		return
	end
	-- Get the info from our array
	SKG_Debug( "selbi = " .. SKG.selectedBidItem )
	local ourItem = SKG.LootItems[SKG.selectedBidItem]
	local mGUID = ourItem.mGUID
	local mName = ourItem.mName
	local mLink = ourItem.link
	SKG_Debug( "mguid = " .. mGUID )
	SKG_Debug( "mname = " .. mName )
	SKG_Debug( "link = " .. mLink )
	
	-- send off the LOOTR event
	local Payload = { mGUID, mName, mLink }
	SKG_SendComm( "LOOTR", Payload, "RAID", nil )
end

function SKG_BidItemOnEnter( i )
	local iLink = SKG_BF_BidItems[i]:GetText()
	if ( iLink ) then
		if ( string.find(iLink, "item") ) then
			GameTooltip:SetOwner( SKG_BidFrame, "ANCHOR_TOPLEFT")
			GameTooltip:SetHyperlink(iLink)
			GameTooltip:Show()
		end
	end
end

function SKG_BidItemButton_OnClick( buttonNum )
	-- This function won't do anything unless we're an admin
	if ( SKG_SECURITY_LEVEL ~= "U" ) then
		local i = buttonNum
		local bText = SKG_BF_BidItems[i]:GetText()
		-- don't do anything if the button has no text on it
		if ( bText ) then
			SKG_Debug( ">>" .. bText .. "<<" )
			if ( SKG.selectedBidItem == buttonNum ) then
				-- just deselect it
				SKG_BF_BidItems[i]:SetNormalTexture( "" )
				SKG_BF_BidItems[i]:SetHighlightTexture( "" )
				SKG.selectedBidItem = 0
			else
				-- deselect whatever was selected
				if ( SKG.selectedBidItem ~= 0 ) then
					local j = SKG.selectedBidItem
					SKG_BF_BidItems[j]:SetNormalTexture( "" )
					SKG_BF_BidItems[j]:SetHighlightTexture( "" )
				end
				-- select the new one
				SKG.selectedBidItem = buttonNum
				SKG_BF_BidItems[i]:SetNormalTexture( [[Interface\Addons\SKG\BLP\highlight]] )
				local nTex = SKG_BF_BidItems[i]:GetNormalTexture()
				nTex:SetAllPoints()
				nTex:SetTexCoord( (30/256), (1-(10/256)), (6/32), (1-(6/32)) )
				SKG_BF_BidItems[i]:SetHighlightTexture( [[Interface\Addons\SKG\BLP\highlight]] )
				local hTex = SKG_BF_BidItems[i]:GetHighlightTexture()
				hTex:SetAllPoints()
				hTex:SetTexCoord( (30/256), (1-(10/256)), (6/32), (1-(6/32)) )
			end
		end
	end
end

function SKG_OpenBid_OnClick( )
	-- add in security eventually

	-- Don't do anything unless we have a raid list selected
	local currList = SKG_ActiveListTitle:GetText()
	if ( ( currList ) and ( currList ~= "Players" ) ) then
		-- don't do anything unless we have a loot item selected
		if ( SKG.selectedBidItem ~= 0 ) then
			-- grab the item link off our button
			local itemLink = SKG_BF_BidItems[SKG.selectedBidItem]:GetText()

			-- Create our final filter based on the lootfilter settings
			-- and the armor modifier
			local finalFilter = SKG_CombineLootFilters()
		
			-- Make sure at least one class can bid:
			if ( finalFilter == "0000000000" ) then
				SKG_Print( SKGL["SKG_MSG_DENYALL"] )
			else
				-- Announce the opening of the bidding
				local msg = SKGL["SKG_MSG_OPENBID"] .. itemLink
				-- use raid warning if the person is a raid assist or raid leader
				if ( IsRaidLeader() or IsRaidOfficer() ) then
					SendChatMessage( msg, "RAID_WARNING" )
				else
					SendChatMessage( msg, "RAID" )
				end
				if ( finalFilter == "1111111111" ) then
					msg = SKGL["SKG_MSG_NOFILTER"]
				else
					local classList = SKG_ClassifyLootFilter( finalFilter )
					msg = SKGL["SKG_MSG_FILTER"] .. classList
					-- Moving this send inside the else to fix SKG-129. If you
					-- change your mind about this later, just move the Send
					-- back outside the if/then so that it sends the NOFILTER
					-- msg again
					SendChatMessage( msg, "RAID" )
				end
				SendChatMessage( SKGL["SKG_MSG_INST"], "RAID" )

				-- Mark me as the opener, and save the filter
				SKG.ManagingBidEvent = true
				SKG.BidFilter = finalFilter

				-- Send the BIDOP event
				local newTID = SKG_CreateTID( 0, 0, 0 )
				local Payload = { newTID, itemLink, finalFilter, currList }
				SKG.BidItem = SKG.selectedBidItem
				SKG_SendComm( "BIDOP", Payload, "RAID", nil )
			end
		else
			SKG_Print( SKGL["SKG_ERROR_NOBIDITEM"] )
		end
	else
		SKG_Print( SKGL["SKG_ERROR_NOLISTSELECTED"] )
	end
end

function SKG_CloseBid_OnClick()
	-- Shouldn't be able to close the bidding unless you're the handler:
	if ( SKG.ManagingBidEvent == true ) then
		local mobGUID = SKG.LootItems[SKG.BidItem].mGUID
		local mobName = SKG.LootItems[SKG.BidItem].mName
		local itemLink = SKG.LootItems[SKG.BidItem].link

		local newTID = SKG_CreateTID( 0, 0, 0 )
		local Payload = { newTID, mobGUID, mobName, itemLink }
		SKG_SendComm( "BIDCL", Payload, "RAID", nil )
	end
end

function SKG_Bid_OnClick( )
	local sender = UnitName( "player" )
	-- only validation on this end is whether we're in a raid or not
	-- everything else will get handled by the event handler
	if ( #SKG.Raiders ~= 0 ) then
		-- we're in a raid
		SKG_SendComm( "BIDBD", sender, "RAID", nil )
	end
	-- grey myself out and highlight the retract button
	SKG_BF_BidButton:Disable()
	SKG_BF_RetractButton:Enable()
end

function SKG_Retract_OnClick( )
	local sender = UnitName( "player" )
	-- only validation on this end is whether we're in a raid or not
	-- everything else will get handled by the event handler
	if ( #SKG.Raiders ~= 0 ) then
		-- we're in a raid
		SKG_SendComm( "BIDRT", sender, "RAID", nil )
	end
	-- re-enable bid
	SKG_BF_BidButton:Enable()
	SKG_BF_RetractButton:Disable()
end

function SKG_UpdateBidderPanel()
	-- Easy peasy. Just display the first entries to our current valid
	-- bidders list.
	SKG_Debug( "in update bidder panel")
	local sortedBidders = {}
	for k, v in pairs( SKG.Bidders ) do
		SKG_Debug( "looping bidders")
		local i = 1
		if ( next( sortedBidders ) == nil ) then
			SKG_Debug( "sorted is empty")
			sortedBidders[i] = k
		else
			SKG_Debug( "sorted is not empty")
			local inserted = false
			while ( i <= #sortedBidders ) do
				if ( k < sortedBidders[i] ) then
					tinsert( sortedBidders, i, k )
					inserted = true
					break
				end
				i = i + 1
			end
			if ( inserted == false ) then
				SKG_Debug( "inserting")
				tinsert( sortedBidders, k )
			end
		end
	end
	for i = 1, SKG_maxVisibleBidders do
		if ( sortedBidders[i] ) then
			SKG_Debug( "darawing name")
			SKG_BF_Bidders[i]:SetText( sortedBidders[i] ..
				": " .. SKG.Bidders[sortedBidders[i]] )
		else
			SKG_Debug( "drawing empty")
			SKG_BF_Bidders[i]:SetText( "" )
		end
	end
end

-- Loot Thresholds
SKG.lootThresholdSelections = {
	type = "group",
	handler = SKG,
	args = { 
		{
			type = "execute",
			name = SKGL["SKG_LOOTTHRESH_UNCOMMON"],
			desc = SKGL["SKG_LOOTTHRESH_UNCOMMON"],
			func = function( )
				-- Set loot threshold to Uncommon (Green)
				SetLootThreshold( 2 )
				SKG_UpdateLootFilters()
				Dewdrop:Close()
			end,
			order = 1,
		},
		{
			type = "execute",
			name = SKGL["SKG_LOOTTHRESH_RARE"],
			desc = SKGL["SKG_LOOTTHRESH_RARE"],
			func = function( )
				-- Set loot threshold to Rare (Blue)
				SetLootThreshold( 3 )
				SKG_UpdateLootFilters()
				Dewdrop:Close()
			end,
			order = 2,
		},
		{
			type = "execute",
			name = SKGL["SKG_LOOTTHRESH_EPIC"],
			desc = SKGL["SKG_LOOTTHRESH_EPIC"],
			func = function( )
				-- Set loot threshold to Epic (Purple)
				SetLootThreshold( 4 )
				SKG_UpdateLootFilters()
				Dewdrop:Close()
			end,
			order = 3,
		},
	}
}

-- Looting Types
SKG.lootTypeSelections = {
	type = "group",
	handler = SKG,
	args = { 
		{	-- 1
			type = "execute",
			name = SKGL["SKG_LOOTTYPE_FREEFORALL"],
			desc = SKGL["SKG_LOOTTYPE_FREEFORALL"],
			func = function( )
				-- Set loot type to Free For All
				SetLootMethod( "freeforall" )
				Dewdrop:Close()
			end,
			order = 1,
		},
		{	-- 2
			type = "execute",
			name = SKGL["SKG_LOOTTYPE_ROUNDROBIN"],
			desc = SKGL["SKG_LOOTTYPE_ROUNDROBIN"],
			func = function( )
				-- Set loot type to Round Robin
				SetLootMethod( "roundrobin" )
				Dewdrop:Close()
			end,
			order = 2,
		},
		{	-- 3
			type = "group",
			name = SKGL["SKG_LOOTTYPE_MASTERLOOTER"],
			desc = SKGL["SKG_LOOTTYPE_MASTERLOOTER"],
			order = 3,
			args = { },
		},
		{	-- 4
			type = "execute",
			name = SKGL["SKG_LOOTTYPE_GROUPLOOT"],
			desc = SKGL["SKG_LOOTTYPE_GROUPLOOT"],
			func = function( )
				-- Set loot type to Group Loot
				SetLootMethod( "group" )
				Dewdrop:Close()
			end,
			order = 4,
		},
		{	-- 5
			type = "execute",
			name = SKGL["SKG_LOOTTYPE_NEEDBEFOREGREED"],
			desc = SKGL["SKG_LOOTTYPE_NEEDBEFOREGREED"],
			func = function( )
				-- Set loot type to Uncommon (Green)
				SetLootMethod( "needbeforegreed" )
				Dewdrop:Close()
			end,
			order = 5,
		},
	}
}

-- Bid Frame creation

SKG_BidFrame = CreateFrame( "Frame", "SKG_BidFrame", SKG_Frame )
	SKG_BidFrame:SetClampedToScreen( true )
	SKG_BidFrame:SetHeight( 399 )
	SKG_BidFrame:SetWidth( 256 )
	SKG_BidFrame:SetPoint( "TOPLEFT", SKG_Frame, "TOPRIGHT", -15, -50 )
	SKG_BidFrame:EnableMouse( true )
	SKG_BidFrame:SetMovable( true )
	SKG_BidFrame:SetFrameLevel( 1 )
	SKG_BidFrame:SetFrameStrata( "BACKGROUND" )
	SKG_BidFrame:SetHitRectInsets( 5, 5, 5, 5 )
	SKG_BidFrame:Hide()

	local SKG_BF_Texture = SKG_BidFrame:CreateTexture( "SKG_BF_Texture", "ARTWORK" )
		SKG_BF_Texture:SetTexture( [[Interface\Addons\SKG\BLP\BidFrame_Texture]] )
		SKG_BF_Texture:SetAllPoints( SKG_BidFrame )
		SKG_BF_Texture:SetTexCoord( 0, 1, 0, ( 399 / 512 ) )

	local SKG_BF_TitleText = SKG_BidFrame:CreateFontString( "SKG_BF_TitleText", "OVERLAY", "GameFontHighlight" )
		SKG_BF_TitleText:SetText( SKGL["SKG_LBL_BF_TITLE_TEXT"] )
		SKG_BF_TitleText:SetPoint( "TOP", SKG_BidFrame, "TOP", 0, -4 )
		SKG_BF_TitleText:SetJustifyH( "CENTER" )
		SKG_BF_TitleText:SetHeight( 14 )
		SKG_BF_TitleText:SetWidth( 200 )

	local SKG_BF_LootTypeButton = SKG_CreateButton( "SKG_BF_LootTypeButton", SKG_BidFrame, 21, 100,
		"TOPLEFT", SKG_BidFrame, "TOPLEFT", 32, -30, "GameFontNormalSmall", "GameFontHighlightSmall",
		SKGL["SKG_LBL_BF_LOOTTYPE_TEXT"], "CENTER", "SKG_BF_LOOTTYPE_TT" )

		SKG_BF_LootTypeButton:SetScript( "OnClick",
			function()
				Dewdrop:Register( this,
					'children', SKG.lootTypeSelections,
					'dontHook', true,
					'point', "TOPRIGHT",
					'relativePoint', "BOTTOMRIGHT"
				)
				this:SetScript( "OnClick",
					function()
						if Dewdrop:IsOpen( this ) then
							Dewdrop:Close()
						else
							Dewdrop:Open( this )
						end
					end
				)
				this:GetScript( "OnClick" )()
			end
		)

	local SKG_BF_LootThreshButton = SKG_CreateButton( "SKG_BF_LootThreshButton", SKG_BidFrame, 21, 100,
		"LEFT", SKG_BF_LootTypeButton, "RIGHT", 13, 0, "GameFontNormalSmall", "GameFontHighlightSmall",
		SKGL["SKG_LBL_BF_THRESH_TEXT"], "CENTER", "SKG_BF_THRESH_TT" )

		SKG_BF_LootThreshButton:SetScript( "OnClick",
			function()
				Dewdrop:Register( this,
					'children', SKG.lootThresholdSelections,
					'dontHook', true,
					'point', "TOPRIGHT",
					'relativePoint', "BOTTOMRIGHT"
				)
				this:SetScript( "OnClick",
					function()
						if Dewdrop:IsOpen( this ) then
							Dewdrop:Close()
						else
							Dewdrop:Open( this )
						end
					end
				)
				this:GetScript( "OnClick" )()
			end
		)

	SKG_BF_BidItems = { }
	for i = 1,SKG_maxVisibleBidItems do
		local Temp_BidItem = SKG_CreateButton("SKG_BF_BidItems" .. i, SKG_BidFrame, 18, 200,
			"TOP", SKG_BidFrame, "TOP", -10, -62, "GameFontNormalSmall", "GameFontHighlightSmall",
			"", "LEFT", "", 1 )
		Temp_BidItem:SetPoint( "TOPLEFT", SKG_BF_LootTypeButton, "BOTTOMLEFT", 0, -11 )
		if not ( i == 1 ) then
			Temp_BidItem:SetPoint( "TOPLEFT", SKG_BF_BidItems[i-1], "BOTTOMLEFT", 0, -1 )
		end
		Temp_BidItem:SetText( "Testing" )
		Temp_BidItem:SetScript( "OnClick",
		function ()
			SKG_BidItemButton_OnClick( i )
		end )
		Temp_BidItem:SetScript( "OnEnter",
		function ()
			SKG_BidItemOnEnter( i )
		end )
		Temp_BidItem:SetScript( "OnLeave",
		function ()
			GameTooltip:Hide()
		end )

		Temp_BidItem:Show()

		SKG_BF_BidItems[i] = Temp_BidItem
	end

	local SKG_BF_BidButton = SKG_CreateButton( "SKG_BF_BidButton", SKG_BidFrame, 21, 100,
		"LEFT", SKG_BidFrame, "LEFT", 30, -9, "GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG__BID"], "CENTER", "SKG_BF_BID_TT" )

		SKG_BF_BidButton:SetScript( "OnClick",
		function ()
			SKG_Bid_OnClick( )
		end )

	local SKG_BF_RetractButton = SKG_CreateButton( "SKG_BF_RetractButton", SKG_BidFrame, 21, 100,
		"RIGHT", SKG_BidFrame, "RIGHT", -15, -9, "GameFontNormalSmall", "GameFontHighlightSmall",
		SKGL["SKG__RETRACT"], "CENTER", "SKG_BF_RETRACT_TT" )

		SKG_BF_RetractButton:SetScript( "OnClick",
		function ()
			SKG_Retract_OnClick( )
		end )

	SKG_BF_Bidders = { }
	for i = 1,SKG_maxVisibleBidders do
		local Temp_Bidder = SKG_CreateButton("SKG_BF_Bidders" .. i, SKG_BidFrame, 18, 200,
			"TOP", SKG_BidFrame, "TOP", -10, -200, "GameFontNormalSmall", "GameFontHighlightSmall",
			"", "LEFT", "", 1 )
		Temp_Bidder:SetPoint( "TOPLEFT", SKG_BF_BidButton, "BOTTOMLEFT", 0, -6 )
		if not ( i == 1 ) then
			Temp_Bidder:SetPoint( "TOPLEFT", SKG_BF_Bidders[i-1], "BOTTOMLEFT", 0, -1 )
		end
		Temp_Bidder:SetText( "Testing" )
		Temp_Bidder:Show()

		SKG_BF_Bidders[i] = Temp_Bidder
	end

-- Bid Button Frame functions

SKG.classFilterSelections = {
	type = "group",
	handler = SKG,
	args = { 
		{
			type = "group",
			name = SKGL["SKG_CLASS_PRESET_FILTERS"],
			desc = SKGL["SKG_CLASS_PRESET_FILTERS"],
			order = 101,
			args = {
				{
					type = "execute",
					name = SKGL["SKG__ALL"],
					desc = SKGL["SKG_ALL_CLASSES"],
					func = function( )
						SKG_SetLootFilter( "1111111111" );
						Dewdrop:Close()
					end,
					order = 1,
				},
				{
					type = "execute",
					name = SKGL["SKG__NONE"],
					desc = SKGL["SKG_NO_CLASSES"],
					func = function( )
						SKG_SetLootFilter( "0000000000" );
						Dewdrop:Close()
					end,
					order = 2,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_TANKS"],
					desc = SKGL["SKG_CLASS_TANKS_DESC"],
					func = function( )
						SKG_SetLootFilter( "1001000011" );
						Dewdrop:Close()
					end,
					order = 3,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_HEALERS"],
					desc = SKGL["SKG_CLASS_HEALERS_DESC"],
					func = function( )
						SKG_SetLootFilter( "1001101000" );
						Dewdrop:Close()
					end,
					order = 4,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_PHYDPS"],
					desc = SKGL["SKG_CLASS_PHYDPS_DESC"],
					func = function( )
						SKG_SetLootFilter( "1101011011" );
						Dewdrop:Close()
					end,
					order = 5,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_MAGDPS"],
					desc = SKGL["SKG_CLASS_MAGDPS_DESC"],
					func = function( )
						SKG_SetLootFilter( "1011101100" );
						Dewdrop:Close()
					end,
					order = 6,
				},
			},
		},
		{
			type = "group",
			name = SKGL["SKG_CLASS_MANUAL"],
			desc = SKGL["SKG_CLASS_MANUAL"],
			order = 102,
			args = {
				{
					type = "execute",
					name = SKGL["SKG_CLASS_DRUID"],
					desc = SKGL["SKG_CLASS_DRUID"],
					func = function( )
						SKG_SetSingleLootFilter( "1000000000" )
						Dewdrop:Close()
					end,
					order = 1,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_HUNTER"],
					desc = SKGL["SKG_CLASS_HUNTER"],
					func = function( )
						SKG_SetSingleLootFilter( "0100000000" )
						Dewdrop:Close()
					end,
					order = 2,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_MAGE"],
					desc = SKGL["SKG_CLASS_MAGE"],
					func = function( )
						SKG_SetSingleLootFilter( "0010000000" )
						Dewdrop:Close()
					end,
					order = 3,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_PALADIN"],
					desc = SKGL["SKG_CLASS_PALADIN"],
					func = function( )
						SKG_SetSingleLootFilter( "0001000000" )
						Dewdrop:Close()
					end,
					order = 4,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_PRIEST"],
					desc = SKGL["SKG_CLASS_PRIEST"],
					func = function( )
						SKG_SetSingleLootFilter( "0000100000" )
						Dewdrop:Close()
					end,
					order = 5,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_ROGUE"],
					desc = SKGL["SKG_CLASS_ROGUE"],
					func = function( )
						SKG_SetSingleLootFilter( "0000010000" )
						Dewdrop:Close()
					end,
					order = 6,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_SHAMAN"],
					desc = SKGL["SKG_CLASS_SHAMAN"],
					func = function( )
						SKG_SetSingleLootFilter( "0000001000" )
						Dewdrop:Close()
					end,
					order = 7,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_WARLOCK"],
					desc = SKGL["SKG_CLASS_WARLOCK"],
					func = function( )
						SKG_SetSingleLootFilter( "0000000100" )
						Dewdrop:Close()
					end,
					order = 8,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_WARRIOR"],
					desc = SKGL["SKG_CLASS_WARRIOR"],
					func = function( )
						SKG_SetSingleLootFilter( "0000000010" )
						Dewdrop:Close()
					end,
					order = 9,
				},
				{
					type = "execute",
					name = SKGL["SKG_CLASS_DEATHKNIGHT"],
					desc = SKGL["SKG_CLASS_DEATHKNIGHT"],
					func = function( )
						SKG_SetSingleLootFilter( "0000000001" )
						Dewdrop:Close()
					end,
					order = 10,
				},
			},
		},
	},2
}

SKG_BFF_ClassFilterText = {}

SKG.armorFilterSelections = {
	type = "group",
	handler = SKG,
	args = { 
		{
			type = "execute",
			name = SKGL["SKG_ARMOR_NONE"],
			desc = SKGL["SKG_ARMOR_NONE_DESC"],
			func = function( )
				SKG.db.profile.Options.Bid.ArmorFilter = 0 -- None
				SKG_BBF_ArmorFilterText:SetText(
					SKGL["SKG_LBL_BBF_ARMORFILTER_TEXT_NONEFULL"] )
				Dewdrop:Close()
			end,
			order = 1,
		},
		{
			type = "execute",
			name = SKGL["SKG_ARMOR_LOOSE"],
			desc = SKGL["SKG_ARMOR_LOOSE_DESC"],
			func = function( )
				SKG.db.profile.Options.Bid.ArmorFilter = 1 -- Loose
				SKG_BBF_ArmorFilterText:SetText(
					SKGL["SKG_LBL_BBF_ARMORFILTER_TEXT_LOOSEFULL"] )
				Dewdrop:Close()
			end,
			order = 2,
		},
		{
			type = "execute",
			name = SKGL["SKG_ARMOR_STRICT"],
			desc = SKGL["SKG_ARMOR_STRICT_DESC"],
			func = function( )
				SKG.db.profile.Options.Bid.ArmorFilter = 2 -- Strict
				SKG_BBF_ArmorFilterText:SetText(
					SKGL["SKG_LBL_BBF_ARMORFILTER_TEXT_STRICTFULL"] )
				Dewdrop:Close()
			end,
			order = 3,
		},
	}
}
-- Bid Button Frame creation

SKG_BidButtonFrame = CreateFrame( "Frame", "SKG_BidButtonFrame", SKG_BidFrame )
	SKG_BidButtonFrame:SetClampedToScreen( true )
	SKG_BidButtonFrame:SetHeight( 347 )
	SKG_BidButtonFrame:SetWidth( 215 )
	SKG_BidButtonFrame:SetPoint( "TOPLEFT", SKG_BidFrame, "TOPRIGHT", 0, -20 )
	SKG_BidButtonFrame:EnableMouse( true )
	SKG_BidButtonFrame:SetMovable( true )
	SKG_BidButtonFrame:SetFrameLevel( 1 )
	SKG_BidButtonFrame:SetFrameStrata( "BACKGROUND" )
	SKG_BidButtonFrame:SetHitRectInsets( 5, 5, 5, 5 )
	SKG_BidButtonFrame:Hide()

	local SKG_BBF_Texture = SKG_BidButtonFrame:CreateTexture( "SKG_BBF_Texture", "ARTWORK" )
		SKG_BBF_Texture:SetTexture( [[Interface\Addons\SKG\BLP\BidButtonFrame_Texture]] )
		SKG_BBF_Texture:SetAllPoints( SKG_BidButtonFrame )
		SKG_BBF_Texture:SetTexCoord( ( ( 256 - 215 ) / 210 ), 1, 0, ( 347 / 512 ) )

	local SKG_BBF_ClassFilterChooser = SKG_CreateButton(
		"SKG_BBF_ClassFilterChooser", SKG_BidButtonFrame, 21, 170,
		"TOPLEFT", SKG_BidButtonFrame, "TOPLEFT", 10, -30,
		"GameFontNormalSmall", "GameFontHighlightSmall",
		SKGL["SKG_LBL_BBF_CLASSCHOOSER_TEXT"], "CENTER", "SKG_BBF_CLASSCHOOSER_TT" )

		SKG_BBF_ClassFilterChooser:SetScript( "OnClick",
			function()
				Dewdrop:Register( this,
					'children', SKG.classFilterSelections,
					'dontHook', true,
					'point', "TOPRIGHT",
					'relativePoint', "BOTTOMRIGHT"
				)
				this:SetScript( "OnClick",
					function()
						if Dewdrop:IsOpen( this ) then
							Dewdrop:Close()
						else
							Dewdrop:Open( this )
						end
					end
				)
				this:GetScript( "OnClick" )()
			end
		)

	for index = 1, SKG.numClasses do
		local tempT = SKG_BidButtonFrame:CreateFontString( "tempT", "OVERLAY", "GameFontNormalSmall" )
		tempT:SetHeight( 14 )
		tempT:SetWidth( 120 )
		tempT:SetJustifyH( "LEFT" )

		cRow = floor( (index-1) / 2 )
		if IsOdd( index ) then
			hPos = 0
		else
			hPos = 100
		end
		tempT:SetPoint( "TOPLEFT", SKG_BBF_ClassFilterChooser, "BOTTOMLEFT", hPos, 0 - (cRow * 15) )
		tempT:SetText( "[ X ] " .. SKG_ClassNames[index] )
		tempT:SetTextColor( 0, 0, 0 )

		SKG_BFF_ClassFilterText[index] = tempT
	end

	local SKG_BBF_ArmorFilterChooser = SKG_CreateButton(
		"SKG_BBF_ArmorFilterChooser", SKG_BidButtonFrame, 21, 170,
		"TOPLEFT", SKG_BBF_ClassFilterChooser, "BOTTOMLEFT", 0, -85,
		"GameFontNormalSmall", "GameFontHighlightSmall",
		SKGL["SKG_LBL_BBF_ARMORCHOOSER_TEXT"], "CENTER", "SKG_BBF_ARMORCHOOSER_TT" )

		SKG_BBF_ArmorFilterChooser:SetScript( "OnClick",
			function()
				Dewdrop:Register( this,
					'children', SKG.armorFilterSelections,
					'dontHook', true,
					'point', "TOPRIGHT",
					'relativePoint', "BOTTOMRIGHT"
				)
				this:SetScript( "OnClick",
					function()
						if Dewdrop:IsOpen( this ) then
							Dewdrop:Close()
						else
							Dewdrop:Open( this )
						end
					end
				)
				this:GetScript( "OnClick" )()
			end
		)

-- Set Text to full text now...
	local SKG_BBF_ArmorFilterText = SKG_BidButtonFrame:CreateFontString( "SKG_BBF_ArmorFilterText", "OVERLAY", "GameFontNormalSmall" )
		SKG_BBF_ArmorFilterText:SetPoint( "TOPLEFT", SKG_BBF_ArmorFilterChooser, "BOTTOMLEFT", 0, -2 )
		SKG_BBF_ArmorFilterText:SetHeight( 150 )
		SKG_BBF_ArmorFilterText:SetWidth( 180 )
		SKG_BBF_ArmorFilterText:SetJustifyH( "LEFT" )
		SKG_BBF_ArmorFilterText:SetJustifyV( "TOP" )
		SKG_BBF_ArmorFilterText:SetText( SKGL["SKG_LBL_BBF_ARMORFILTER_TEXT_LOOSEFULL"] )
		SKG_BBF_ArmorFilterText:SetTextColor( 0, 0, 0 )

	local SKG_BBF_OpenBidButton = SKG_CreateButton(
		"SKG_BBF_OpenBidButton", SKG_BidButtonFrame, 21, 170,
		"TOPLEFT", SKG_BBF_ArmorFilterChooser, "BOTTOMLEFT", 0, -85,
		"GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG__OPENBID"], "CENTER", "SKG_BBF_OPENBID_TT" )

		SKG_BBF_OpenBidButton:SetScript( "OnClick",
		function ()
			SKG_OpenBid_OnClick( )
		end )

	local SKG_BBF_CloseBidButton = SKG_CreateButton(
		"SKG_BBF_CloseBidButton", SKG_BidButtonFrame, 21, 170,
		"TOPLEFT", SKG_BBF_OpenBidButton, "BOTTOMLEFT", 0, -2,
		"GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG__CLOSEBID"], "CENTER", "SKG_BBF_CLOSEBID_TT" )

		SKG_BBF_CloseBidButton:SetScript( "OnClick",
		function ()
			SKG_CloseBid_OnClick( )
		end )

	local SKG_BBF_RemoveItemButton = SKG_CreateButton(
		"SKG_BBF_RemoveItemButton", SKG_BidButtonFrame, 21, 170,
		"TOPLEFT", SKG_BBF_CloseBidButton, "BOTTOMLEFT", 0, -2,
		"GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG_LBL_BBF_REMOVEITEM_TEXT"], "CENTER", "SKG_BBF_REMOVEITEM_TT" )

		SKG_BBF_RemoveItemButton:SetScript( "OnClick",
		function ()
			SKG_RemoveBidItem_OnClick( )
		end )

	local SKG_BBF_ForceRetractButton = SKG_CreateButton(
		"SKG_BBF_ForceRetractButton", SKG_BidButtonFrame, 21, 170,
		"TOPLEFT", SKG_BBF_RemoveItemButton, "BOTTOMLEFT", 0, -2,
		"GameFontNormalSmall", "GameFontHighlightSmall",
		SKGL["SKG_LBL_BBF_FORCERETRACT_TEXT"], "CENTER", "SKG_BBF_FORCERETRACT_TT" )
	-- Disable until I put the code in:
	SKG_BBF_ForceRetractButton:Disable()

-- OnLoad stuff here

--[[
************************************************************************
CHANGELOG:

Date : 12/22/08
	Added support for Death Knights.

Date : 10/25/08
	Initial attempt with Ace3 instead of LibRock. Probably will require
	major edits once. Added header/footer. Found bug in SetSingleLootFilter
	for druids.
************************************************************************
]]--
