--[[
************************************************************************
Project				: SKG
Author				: zhinjio
Project Revision	: r136
Project Date		: 20090516063018

File				: modAdmin\Core.lua
Commit Author		: zhinjio
Commit Revision		: 120
Commit Date			: 20081222091749
************************************************************************
Description	:
	Functions and definition for the admin module and frame. These are
	only used if you are a guild leader.

TODO		:
	Repair on the onload stuff once 3.0.3 comes out and LoD is fixed.

************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]

-- addon:SetDefaultModuleState( state )

local SKG = LibStub( "AceAddon-3.0"):GetAddon( "SKG" )
SKG:SetDefaultModuleState( false )

local SKGAdmin = SKG:NewModule( "SKGAdmin", "AceComm-3.0" )
local Tablet = LibStub( "Tablet-2.0" )
local SKGL = LibStub( "AceLocale-3.0"):GetLocale( "SKG" )

local self = SKGAdmin
local mod = SKGAdmin

function mod:OnEnable()
	local db = SKG.SecurityInfo
	-- Stuff to do when activated...
	-- if we don't have the standard security structure initialized, do so:

	if not ( db.Proxy ) then
		db.RankBasedAuth = true
		db.AuthRank = 1
		db.ManualAuthList = {}
		db.UseProxy = false
		db.Proxy = ""
	end

	SKG_SF_InitValues()
end

function SKG_SF_InitValues()
	local db = SKG.SecurityInfo

	-- sort the ManualAuthList, if there is one
	if ( #db.ManualAuthList ~= 0 ) then
		table.sort( db.ManualAuthList )
	end

	-- I'm gonna call GuildRoster again just for kicks...
	GuildRoster()

	-- Assign the ranks in the security chooser
	-- Only do this if the chooser is currently empty.
	SKG_Debug( "in initvalues" )
	if ( next( SKG.RankChooserOptions.args ) == nil ) then
		SKG_Debug( "list is empty" )
		for index = 1, GuildControlGetNumRanks() do
			SKG_Debug( "in index ... " .. index )
			local t = {
				type = "execute",
				name = GuildControlGetRankName(index),
				desc = GuildControlGetRankName(index),
				func = function( value )
					SKG_SF_CurrentRankText:SetText(
						SKGL["SKG_LBL_SF_CURRENTRANK_TEXT"] .. GuildControlGetRankName(value) )
					db.AuthRank = value - 1
					Dewdrop:Close()
				end,
				passValue = index,
				order = 100 + index,
			}
			tinsert( SKG.RankChooserOptions.args, t )
		end
	end

	-- this doesn't hurt anything to execute more than once.
	if ( db.RankBasedAuth ) then
		SKG_SF_RankBasedCB:SetChecked( true )
		SKG_SF_ManualAuthCB:SetChecked( false )
		SKG_SF_RankChooser:Enable()
		SKG_EnableNormalText( SKG_SF_CurrentRankText )
		SKG_SF_CurrentRankText:SetText( SKGL["SKG_LBL_SF_CURRENTRANK_TEXT"] ..
			GuildControlGetRankName( db.AuthRank + 1 ) )
			SKG_SF_AuthListHover:Disable()
	else
		SKG_SF_RankBasedCB:SetChecked( false )
		SKG_SF_ManualAuthCB:SetChecked( true )
		SKG_SF_RankChooser:Disable()
		SKG_DisableNormalText( SKG_SF_CurrentRankText )
		SKG_SF_AuthListHover:Enable()
	end

	-- This can execute more than once:
	if ( db.UseProxy ) then
		SKG_SF_ProxyCB:SetChecked( true )
		SKG_SF_ProxyUserText:SetText( SKGL["SKG_LBL_SF_PROXYUSER_TEXT"] .. " " .. db.Proxy )
	else
		SKG_SF_ProxyCB:SetChecked( false )
		if ( db.Proxy == "" ) then
			SKG_SF_ProxyCB:Disable()
			SKG_DisableNormalText( SKG_SF_ProxyCBText )
			SKG_SF_ProxyUserText:SetText( SKGL["SKG_LBL_SF_PROXYUSER_TEXT"] )
			SKG_DisableNormalText( SKG_SF_ProxyUserText )
		else
			SKG_SF_ProxyCB:Enable()
			SKG_SF_ProxyUserText:SetText( SKGL["SKG_LBL_SF_PROXYUSER_TEXT"] .. " " .. db.Proxy )
			SKG_EnableNormalText( SKG_SF_ProxyUserText )
		end
	end
	
	-- If our security level is only "P", then disable the proxy stuff
	-- If we're "A", enable it
	SKG_Debug( "ssl = " .. SKG_SECURITY_LEVEL )
	if ( SKG_SECURITY_LEVEL == "P" ) then
		SKG_Debug( "Only Proxy ... Disabling" )
		SKG_SF_ProxyCB:Disable()
		SKG_DisableNormalText( SKG_SF_ProxyCBText )
		SKG_DisableNormalText( SKG_SF_ProxyUserText )
		SKG_SF_AddProxyButton:Disable()
	elseif ( SKG_SECURITY_LEVEL == "A" ) then
		SKG_Debug( "Admin, enable proxy stuff" )
		SKG_SF_ProxyCB:Enable()
		SKG_EnableNormalText( SKG_SF_ProxyCBText )
		SKG_EnableNormalText( SKG_SF_ProxyUserText )
		SKG_SF_AddProxyButton:Enable()
	end

	-- Fill in the guild player chooser
	-- This also should only happen if the chooser is empty
	if ( next( SKG.GuildPlayerChooserOptions.args ) == nil ) then
		-- The next sort is via class. Add each class to each rank menu
		for classIndex = 1, SKG.numClasses do
			local u = {
				type = "group",
				name = SKG_ClassNames[classIndex],
				desc = SKG_ClassNames[classIndex],
				order = 100 + classIndex,
				args = { },
			}
			tinsert( SKG.GuildPlayerChooserOptions.args, u )

			-- And finally, an alphabetic grouping...
			for alphaIndex = 1, 5 do
				if ( alphaIndex == 1 ) then
					nameDesc = "A-C"
				elseif ( alphaIndex == 2 ) then
					nameDesc = "D-F"
				elseif ( alphaIndex == 3 ) then
					nameDesc = "G-L"
				elseif ( alphaIndex == 4 ) then
					nameDesc = "M-R"
				else
					nameDesc = "S-Z"
				end

				local v = {
					type = "group",
					name = nameDesc,
					desc = nameDesc,
					order = 100 + alphaIndex,
					args = { },
				}
				tinsert( SKG.GuildPlayerChooserOptions.args[classIndex].args, v )
			end
		end

		-- and now, individual players. Don't put an order in, it'll sort 'em
		-- alphabetically
		numGuildMembers = GetNumGuildMembers(true)
		for index = 1, numGuildMembers do
			local toonName, gRank = 0
			local toonName, gRank, g, l, toonClass = GetGuildRosterInfo(index);			

			-- Parse out where its going to go in our tree.
			for i,v in ipairs( SKG_ClassNames ) do
				if ( v == toonClass ) then CI = i end
			end
			local AI = alphaIndex( toonName )

			local t = {
				type = "execute",
				name = "" .. toonName,
				desc = "" .. toonName,
				func = function( value )
					SKG_SelectedPlayerName = value
					SKG_SF_SelectedPlayerText:SetText(
						SKGL["SKG_LBL_SF_CURRENTPLAYER_TEXT"] .. value )
					-- Enable the selected player action buttons
					SKG_SF_AddAuthButton:Enable()
					SKG_SF_DelAuthButton:Enable()
					-- Only enable if we're A (not P)
					if ( SKG_SECURITY_LEVEL == "A" ) then
						SKG_SF_AddProxyButton:Enable()
					else
						SKG_SF_AddProxyButton:Disable()
					end
					Dewdrop:Close()
				end,
				passValue = toonName,
			}
			tinsert( SKG.GuildPlayerChooserOptions.args[CI].args[AI].args, t )
		end

		-- Now that the full list is in there, remove entries that are empty
		for cI = 9, 1, -1 do
			for aI = 5, 1, -1 do
				if ( #SKG.GuildPlayerChooserOptions.args[cI].args[aI].args == 0 ) then
					tremove( SKG.GuildPlayerChooserOptions.args[cI].args, aI )
				end
			end
			if ( next( SKG.GuildPlayerChooserOptions.args[cI].args ) == nil ) then
				tremove( SKG.GuildPlayerChooserOptions.args, cI )
			end
		end
	end
end

function SKG_SF_AuthCB_Clicked()
	local db = SKG.SecurityInfo

	if ( db.RankBasedAuth ) then
		SKG_SF_RankBasedCB:SetChecked( false )
		SKG_SF_ManualAuthCB:SetChecked( true )
		db.RankBasedAuth = false
		SKG_SF_RankChooser:Disable()
		SKG_DisableNormalText( SKG_SF_CurrentRankText )
		SKG_SF_AuthListHover:Enable()
		if ( SKG_SelectedPlayerName ~= "" ) then
			SKG_SF_AddAuthButton:Enable()
			SKG_SF_DelAuthButton:Enable()
		end
	else
		SKG_SF_RankBasedCB:SetChecked( true )
		SKG_SF_ManualAuthCB:SetChecked( false )
		SKG_SF_RankChooser:Enable()
		SKG_EnableNormalText( SKG_SF_CurrentRankText )
		db.RankBasedAuth = true
		if ( db.AuthRank ) then
			SKG_SF_CurrentRankText:SetText( SKGL["SKG_LBL_SF_CURRENTRANK_TEXT"] ..
				GuildControlGetRankName( db.AuthRank ) )
		else
			SKG_SF_CurrentRankText:SetText( SKGL["SKG_LBL_SF_CURRENTRANK_TEXT"] )
		end
		SKG_SF_AuthListHover:Disable()
		SKG_SF_AddAuthButton:Disable()
		SKG_SF_DelAuthButton:Disable()
	end
end

function SKG_SF_AddAuth_OnClick()
	local db = SKG.SecurityInfo
	if ( SKG_SelectedPlayerName ~= "" ) then
		if ( #db.ManualAuthList == 10 ) then
			SKG_Print( SKGL["SKG_SF_ERROR_TOOMANYMANUAL"] )
		else
			-- are they already in the list?
			local found = false
			for i = 1, #db.ManualAuthList do
				if ( db.ManualAuthList[i] == SKG_SelectedPlayerName ) then
					found = true
					break
				end
			end
			if ( not found ) then
				tinsert( db.ManualAuthList, SKG_SelectedPlayerName )
				-- close the tooltip thinger
				if ( not Tablet:IsAttached( SKG_SF_AuthListHover ) ) then
					Tablet:Attach( SKG_SF_AuthListHover )
				end
				table.sort( db.ManualAuthList )
			end
		end
	end
end

function SKG_SF_DelAuth_OnClick()
	local db = SKG.SecurityInfo
	if ( SKG_SelectedPlayerName ~= "" ) then
		-- are they already in the list?
		local found = 0
		for i = 1, #db.ManualAuthList do
			if ( db.ManualAuthList[i] == SKG_SelectedPlayerName ) then
				found = i
				break
			end
		end
		if ( found ~= 0 ) then
			tremove( db.ManualAuthList, found )
			-- close the tooltip thinger
			if ( not Tablet:IsAttached( SKG_SF_AuthListHover ) ) then
				Tablet:Attach( SKG_SF_AuthListHover )
			end
		end
	end

end

function SKG_SF_ProxyCB_Clicked()
	local db = SKG.SecurityInfo

	if ( db.UseProxy ) then
		db.UseProxy = false
		SKG_SF_ProxyCB:SetChecked( false )
	else
		if ( db.Proxy == "" ) then	
			SKG_Print( SKGL["SKG_SF_ERROR_NOPROXYUSER"] )
			SKG_SF_ProxyCB:SetChecked( false )
		else
			db.UseProxy = true
			SKG_SF_ProxyCB:SetChecked( true )
		end
	end
end

function SKG_SF_AddProxy_OnClick( )
	local db = SKG.SecurityInfo
	if ( SKG_SelectedPlayerName ~= "" ) then
		db.Proxy = SKG_SelectedPlayerName
		SKG_SF_ProxyUserText:SetText( SKGL["SKG_LBL_SF_PROXYUSER_TEXT"] .. " "
			.. SKG_SelectedPlayerName )
	end
end

function SKG_SF_SendSECUR_Clicked()
	local payload = SKG.SecurityInfo
	SKG_SendComm( "SECUR", payload, "GUILD", nil )
end

SKG.RankChooserOptions = {
	type = "group",
	handler = SKG,
	args = { },
}

SKG.GuildPlayerChooserOptions = {
	type = "group",
	handler = SKG,
	args = { },
}

-- Security Frame Creation

SKG_SecurityFrame = CreateFrame( "Frame", "SKG_SecurityFrame", SKG_Frame )
	SKG_SecurityFrame:SetHeight( 371 )
	SKG_SecurityFrame:SetWidth( 265 )
	SKG_SecurityFrame:SetPoint( "TOPLEFT", SKG_Frame, "TOPRIGHT", -5, -50 )
	SKG_SecurityFrame:EnableMouse( true )
	SKG_SecurityFrame:SetMovable( true )
	SKG_SecurityFrame:SetFrameLevel( 1 )
	SKG_SecurityFrame:SetFrameStrata( "BACKGROUND" )
	SKG_SecurityFrame:SetHitRectInsets( 5, 5, 5, 5 )
	SKG_SecurityFrame:Hide()

	local SKG_SF_Texture = SKG_SecurityFrame:CreateTexture( "SKG_SF_Texture", "ARTWORK" )
		SKG_SF_Texture:SetTexture( [[Interface\Addons\SKG\BLP\SecurityFrame_Texture]] )
		SKG_SF_Texture:SetAllPoints( SKG_OptionsFrame )
		SKG_SF_Texture:SetTexCoord( (( 512 - 265 ) / 512 ), 1, 0, ( 371 / 512 ) )

	local SKG_SF_TitleText = SKG_SecurityFrame:CreateFontString( "SKG_SF_TitleText", "OVERLAY", "GameFontHighlight" )
		SKG_SF_TitleText:SetText( SKGL["SKG_LBL_SF_TITLE_TEXT"] )
		SKG_SF_TitleText:SetPoint( "TOP", SKG_SecurityFrame, "TOP", 0, -3 )
		SKG_SF_TitleText:SetJustifyH( "CENTER" )
		SKG_SF_TitleText:SetHeight( 14 )
		SKG_SF_TitleText:SetWidth( 200 )

	local SKG_SF_SendSECUR = SKG_CreateButton( "SKG_SF_SendSECUR", SKG_SecurityFrame, 24, 200,
		"TOP", SKG_SecurityFrame, "TOP", 0, -28, "GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG_LBL_SF_SENDSECUR_TEXT"], "CENTER", "SKG_SF_SENDSECUR_TT" )

		SKG_SF_SendSECUR:SetScript( "OnClick", SKG_SF_SendSECUR_Clicked )

	local SKG_SF_GuildPlayerChooser = SKG_CreateButton( "SKG_SF_GuildPlayerChooser", SKG_SecurityFrame, 18, 200,
		"TOP", SKG_SecurityFrame, "TOP", 0, -70, "GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG_LBL_SF_GUILDCHOOSER_TEXT"], "CENTER", "SKG_SF_GUILDCHOOSER_TT" )

		SKG_SF_GuildPlayerChooser:SetScript( "OnClick",
			function()
				Dewdrop:Register( this,
					'children', SKG.GuildPlayerChooserOptions,
					'dontHook', true,
					'point', "TOPLEFT",
					'relativePoint', "BOTTOMLEFT"
				)
				this:SetScript( "OnClick",
					function()
						if Dewdrop:IsOpen( this ) then
							Dewdrop:Close()
						else
							Dewdrop:Open( this )
						end
					end
				)
				this:GetScript( "OnClick" )()
			end
		)

	local SKG_SF_SelectedPlayerText = SKG_SecurityFrame:CreateFontString( "SKG_SF_SelectedPlayerText", "OVERLAY", "GameFontNormalSmall" )
		SKG_SF_SelectedPlayerText:SetText( SKGL["SKG_LBL_SF_CURRENTPLAYER_TEXT"] )
		SKG_SF_SelectedPlayerText:SetPoint( "TOP", SKG_SF_GuildPlayerChooser, "TOP", 0, -18 )
		SKG_SF_SelectedPlayerText:SetJustifyH( "CENTER" )
		SKG_SF_SelectedPlayerText:SetHeight( 14 )
		SKG_SF_SelectedPlayerText:SetWidth( 200 )

	local SKG_SF_RankBasedCB = CreateFrame( "CheckButton", "SKG_SF_RankBasedCB", SKG_SecurityFrame, "UICheckButtonTemplate" )
		SKG_SF_RankBasedCB:SetHeight( 24 )
		SKG_SF_RankBasedCB:SetWidth( 24 )
		SKG_SF_RankBasedCB:SetPoint( "TOPLEFT", SKG_SF_SelectedPlayerText, "TOPLEFT", -20, -20 )
		SKG_SF_RankBasedCBText:SetText( SKGL["SKG_LBL_SF_RANKBASEDCB_TEXT"] )

		SKG_SF_RankBasedCB:SetScript( "OnClick", SKG_SF_AuthCB_Clicked )

		SKG_TooltipDisplay( SKG_SF_RankBasedCB, "SKG_SF_RANKBASEDCB_TT", 1 )

	local SKG_SF_RankChooser = SKG_CreateButton( "SKG_SF_RankChooser", SKG_SecurityFrame, 20, 200,
		"TOPLEFT", SKG_SF_RankBasedCB, "BOTTOMLEFT", 30, -2, "GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG_LBL_SF_RANKCHOOSER_TEXT"], "CENTER", "SKG_SF_RANKCHOOSER_TT" )

		SKG_SF_RankChooser:SetScript( "OnClick",
			function()
				Dewdrop:Register( this,
					'children', SKG.RankChooserOptions,
					'dontHook', true,
					'point', "TOPLEFT",
					'relativePoint', "BOTTOMLEFT"
				)
				this:SetScript( "OnClick",
					function()
						if Dewdrop:IsOpen( this ) then
							Dewdrop:Close()
						else
							Dewdrop:Open( this )
						end
					end
				)
				this:GetScript( "OnClick" )()
			end
		)

	local SKG_SF_CurrentRankText = SKG_SecurityFrame:CreateFontString( "SKG_SF_CurrentRankText", "OVERLAY", "GameFontNormal" )
		SKG_SF_CurrentRankText:SetText( SKGL["SKG_LBL_SF_CURRENTRANK_TEXT"] )
		SKG_SF_CurrentRankText:SetPoint( "TOPLEFT", SKG_SF_RankChooser, "BOTTOMLEFT", 2, -2 )
		SKG_SF_CurrentRankText:SetJustifyH( "LEFT" )
		SKG_SF_CurrentRankText:SetHeight( 14 )
		SKG_SF_CurrentRankText:SetWidth( 200 )

	local SKG_SF_ManualAuthCB = CreateFrame( "CheckButton", "SKG_SF_ManualAuthCB", SKG_SecurityFrame, "UICheckButtonTemplate" )
		SKG_SF_ManualAuthCB:SetHeight( 24 )
		SKG_SF_ManualAuthCB:SetWidth( 24 )
		SKG_SF_ManualAuthCB:SetPoint( "TOPLEFT", SKG_SF_RankBasedCB, "BOTTOMLEFT", 0, -50 )
		SKG_SF_ManualAuthCBText:SetText( SKGL["SKG_LBL_SF_MANUALAUTHCB_TEXT"] )

		SKG_SF_ManualAuthCB:SetScript( "OnClick", SKG_SF_AuthCB_Clicked )

		SKG_TooltipDisplay( SKG_SF_ManualAuthCB, "SKG_SF_MANUALAUTHCB_TT", 1 )

	local SKG_SF_AuthListHover = SKG_CreateButton( "SKG_SF_AuthListHover", SKG_SecurityFrame, 20, 200,
		"TOPLEFT", SKG_SF_ManualAuthCB, "BOTTOMLEFT", 30, -2, "GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG_LBL_SF_AUTHHOVER_TEXT"], "CENTER", "SKG_SF_AUTHUSER_TT" )

		Tablet:Register( SKG_SF_AuthListHover, 
			'children', function()
				Tablet:SetTitle( SKGL["SKG_LBL_SF_AUTHHOVER_TEXT"] )
				local cat = Tablet:AddCategory()
				cat:AddLine( '', '' )
				local db = SKG.SecurityInfo
				for i = 1, #db.ManualAuthList do
					cat:AddLine(
						'text', db.ManualAuthList[i],
						'hasCheck', true,
						'checked', true,
						'checkIcon', "Interface\\Addons\\SKG\\BLP\\ChatIcon"
					)
				end
			end,
			'point', function()
				return "BOTTOMLEFT", "TOPRIGHT"
			end,
			'parent', SKG_SF_AuthListHover,
			'hideWhenEmpty', false,
			'showTitleWhenDetached', true,
			'data', {},
			'detachedData', {},
			'strata', "TOOLTIP"
		)
		Tablet:SetFontSizePercent( SKG_SF_AuthListHover, .8 )

		SKG_SF_AuthListHover:SetScript( "OnClick",
			function()
				if ( Tablet:IsAttached( SKG_SF_AuthListHover ) ) then
					Tablet:Open( SKG_SF_AuthListHover )
					Tablet:Detach( SKG_SF_AuthListHover )
				else
					Tablet:Attach( SKG_SF_AuthListHover )
				end	
			end )

	local SKG_SF_AddAuthButton = SKG_CreateButton( "SKG_SF_AddAuthButton", SKG_SecurityFrame, 20, 200,
		"TOPLEFT", SKG_SF_AuthListHover, "BOTTOMLEFT", 0, -2, "GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG_LBL_SF_ADDAUTH_TEXT"], "CENTER", "SKG_SF_ADDUSER_TT" )

		SKG_SF_AddAuthButton:SetScript( "OnClick", SKG_SF_AddAuth_OnClick )
		SKG_SF_AddAuthButton:Disable()

	local SKG_SF_DelAuthButton = SKG_CreateButton( "SKG_SF_DelAuthButton", SKG_SecurityFrame, 20, 200,
 		"TOPLEFT", SKG_SF_AddAuthButton, "BOTTOMLEFT", 0, -2, "GameFontNormalSmall", "GameFontHighlightSmall", 
 		SKGL["SKG_LBL_SF_DELAUTH_TEXT"], "CENTER", "SKG_SF_DELUSER_TT" )

 		SKG_SF_DelAuthButton:SetScript( "OnClick", SKG_SF_DelAuth_OnClick )
 		SKG_SF_DelAuthButton:Disable()

	local SKG_SF_ProxyCB = CreateFrame( "CheckButton", "SKG_SF_ProxyCB", SKG_SecurityFrame, "UICheckButtonTemplate" )
		SKG_SF_ProxyCB:SetHeight( 24 )
		SKG_SF_ProxyCB:SetWidth( 24 )
		SKG_SF_ProxyCB:SetPoint( "TOPLEFT", SKG_SF_ManualAuthCB, "BOTTOMLEFT", 0, -75 )
		SKG_SF_ProxyCBText:SetText( SKGL["SKG_LBL_SF_PROXYCB_TEXT"] )

		SKG_SF_ProxyCB:SetScript( "OnClick", SKG_SF_ProxyCB_Clicked )

		SKG_TooltipDisplay( SKG_SF_ProxyCB, "SKG_SF_PROXYCB_TT", 1 )

	local SKG_SF_ProxyUserText = SKG_SecurityFrame:CreateFontString( "SKG_SF_ProxyUserText", "OVERLAY", "GameFontNormalSmall" )
		SKG_SF_ProxyUserText:SetText( SKGL["SKG_LBL_SF_PROXYUSER_TEXT"] )
		SKG_SF_ProxyUserText:SetPoint( "TOPLEFT", SKG_SF_ProxyCB, "BOTTOMLEFT", 30, -2 )
		SKG_SF_ProxyUserText:SetJustifyH( "LEFT" )
		SKG_SF_ProxyUserText:SetHeight( 14 )
		SKG_SF_ProxyUserText:SetWidth( 200 )

	local SKG_SF_AddProxyButton = SKG_CreateButton( "SKG_SF_AddProxyButton", SKG_SecurityFrame, 20, 200,
		"TOPLEFT", SKG_SF_ProxyUserText, "BOTTOMLEFT", 0, -2, "GameFontNormalSmall", "GameFontHighlightSmall", 
		SKGL["SKG_LBL_SF_ADDPROXY_TEXT"], "CENTER", "SKG_SF_ADDPROXY_TT" )

		SKG_SF_AddProxyButton:SetScript( "OnClick", SKG_SF_AddProxy_OnClick )
		SKG_SF_AddProxyButton:Disable()


--[[
************************************************************************
CHANGELOG:

Date : 10/25/08
	Initial attempt with Ace3 instead of LibRock. Probably will require
	major edits once. Added header/footer. Moved modAdmin.lua into this
	file.
************************************************************************
]]--
